.. CensusData documentation master file, created by
   sphinx-quickstart on Sun Jul  9 18:50:17 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to CensusData's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   geographies
   variables
   example1
   example2
   example3
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
